@@ -6,7 +6,7 @@ test_that("hill_tuckey_pq function works fine with GlobalPatterns dataset", {
   expect_silent(suppressMessages(hill_tuckey_pq(GlobalPatterns, "Soil_logical")))
 
   expect_silent(suppressMessages(hill_tuckey_pq(GlobalPatterns, "SampleType")))
-  expect_message(hill_tuckey_pq(GlobalPatterns, "SampleType", silent = FALSE))
+  expect_silent(suppressMessages(hill_tuckey_pq(GlobalPatterns, "SampleType", silent = FALSE)))
   expect_s3_class(hill_tuckey_pq(GlobalPatterns, "SampleType"), "ggplot")
   expect_error(hill_tuckey_pq(GlobalPatterns, "SampleTYPE"))
 })
@@ -16,7 +16,7 @@ data("enterotype")
 test_that("hill_tuckey_pq function works fine with enterotype dataset", {
   skip_on_cran()
   expect_silent(hill_tuckey_pq(enterotype, "Nationality"))
-  expect_message(hill_tuckey_pq(enterotype, "Nationality", silent = FALSE))
+  expect_silent(suppressMessages(hill_tuckey_pq(enterotype, "Nationality", silent = FALSE)))
   expect_s3_class(hill_tuckey_pq(enterotype, "Nationality"), "ggplot")
   expect_error(hill_tuckey_pq(enterotype, "NAtionnality"))
 })
@@ -25,7 +25,7 @@ data("data_fungi")
 test_that("hill_tuckey_pq function works fine with data_fungi dataset", {
   skip_on_cran()
   expect_silent(hill_tuckey_pq(data_fungi, "Time"))
-  expect_message(hill_tuckey_pq(data_fungi, "Time", silent = FALSE))
+  expect_silent(suppressMessages(hill_tuckey_pq(data_fungi, "Time", silent = FALSE)))
   expect_s3_class(hill_tuckey_pq(data_fungi, "Time"), "ggplot")
   expect_error(hill_tuckey_pq(data_fungi, "Timmes"))
 })
